==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/api/rbac/v1alpha1/ServiceRoleSpecFluent.java <==
package me.snowdrop.istio.api.rbac.v1alpha1;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface ServiceRoleSpecFluent<A extends ServiceRoleSpecFluent<A>> extends Fluent<A>{


    public A addToRules(int index,AccessRule item);
    public A setToRules(int index,AccessRule item);
    public A addToRules(AccessRule... items);
    public A addAllToRules(Collection<AccessRule> items);
    public A removeFromRules(AccessRule... items);
    public A removeAllFromRules(Collection<AccessRule> items);
    
/**
 * This method has been deprecated, please use method buildRules instead.
 * @return The buildable object.
 */
@Deprecated public List<AccessRule> getRules();
    public List<AccessRule> buildRules();
    public AccessRule buildRule(int index);
    public AccessRule buildFirstRule();
    public AccessRule buildLastRule();
    public AccessRule buildMatchingRule(io.fabric8.kubernetes.api.builder.Predicate<AccessRuleBuilder> predicate);
    public A withRules(List<AccessRule> rules);
    public A withRules(AccessRule... rules);
    public Boolean hasRules();
    public ServiceRoleSpecFluent.RulesNested<A> addNewRule();
    public ServiceRoleSpecFluent.RulesNested<A> addNewRuleLike(AccessRule item);
    public ServiceRoleSpecFluent.RulesNested<A> setNewRuleLike(int index,AccessRule item);
    public ServiceRoleSpecFluent.RulesNested<A> editRule(int index);
    public ServiceRoleSpecFluent.RulesNested<A> editFirstRule();
    public ServiceRoleSpecFluent.RulesNested<A> editLastRule();
    public ServiceRoleSpecFluent.RulesNested<A> editMatchingRule(io.fabric8.kubernetes.api.builder.Predicate<AccessRuleBuilder> predicate);

    public interface RulesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,AccessRuleFluent<ServiceRoleSpecFluent.RulesNested<N>>{

        
    public N and();    public N endRule();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/rbac/v1alpha1/ServiceRoleSpecFluent.java <==
package me.snowdrop.istio.api.rbac.v1alpha1;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface ServiceRoleSpecFluent<A extends ServiceRoleSpecFluent<A>> extends Fluent<A>{


    public A addToRules(int index,AccessRule item);
    public A setToRules(int index,AccessRule item);
    public A addToRules(AccessRule... items);
    public A addAllToRules(Collection<AccessRule> items);
    public A removeFromRules(AccessRule... items);
    public A removeAllFromRules(Collection<AccessRule> items);
    public A removeMatchingFromRules(io.fabric8.kubernetes.api.builder.Predicate<AccessRuleBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildRules instead.
 * @return The buildable object.
 */
@Deprecated public List<AccessRule> getRules();
    public List<AccessRule> buildRules();
    public AccessRule buildRule(int index);
    public AccessRule buildFirstRule();
    public AccessRule buildLastRule();
    public AccessRule buildMatchingRule(io.fabric8.kubernetes.api.builder.Predicate<AccessRuleBuilder> predicate);
    public Boolean hasMatchingRule(io.fabric8.kubernetes.api.builder.Predicate<AccessRuleBuilder> predicate);
    public A withRules(List<AccessRule> rules);
    public A withRules(AccessRule... rules);
    public Boolean hasRules();
    public ServiceRoleSpecFluent.RulesNested<A> addNewRule();
    public ServiceRoleSpecFluent.RulesNested<A> addNewRuleLike(AccessRule item);
    public ServiceRoleSpecFluent.RulesNested<A> setNewRuleLike(int index,AccessRule item);
    public ServiceRoleSpecFluent.RulesNested<A> editRule(int index);
    public ServiceRoleSpecFluent.RulesNested<A> editFirstRule();
    public ServiceRoleSpecFluent.RulesNested<A> editLastRule();
    public ServiceRoleSpecFluent.RulesNested<A> editMatchingRule(io.fabric8.kubernetes.api.builder.Predicate<AccessRuleBuilder> predicate);

    public interface RulesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,AccessRuleFluent<ServiceRoleSpecFluent.RulesNested<N>>{

        
    public N and();    public N endRule();
}


}
